# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .agents_search_response_agents_item_created_by_id import AgentsSearchResponseAgentsItemCreatedById
from .agents_search_response_agents_item_last_updated_by_id import AgentsSearchResponseAgentsItemLastUpdatedById
from .agents_search_response_agents_item_created_at import AgentsSearchResponseAgentsItemCreatedAt
from .agents_search_response_agents_item_updated_at import AgentsSearchResponseAgentsItemUpdatedAt
from .agents_search_response_agents_item_tool_rules import AgentsSearchResponseAgentsItemToolRules
from .agents_search_response_agents_item_message_ids import AgentsSearchResponseAgentsItemMessageIds
from .agents_search_response_agents_item_agent_type import AgentsSearchResponseAgentsItemAgentType
from .agents_search_response_agents_item_llm_config import AgentsSearchResponseAgentsItemLlmConfig
from .agents_search_response_agents_item_embedding_config import AgentsSearchResponseAgentsItemEmbeddingConfig
from .agents_search_response_agents_item_organization_id import AgentsSearchResponseAgentsItemOrganizationId
from .agents_search_response_agents_item_description import AgentsSearchResponseAgentsItemDescription
from .agents_search_response_agents_item_metadata import AgentsSearchResponseAgentsItemMetadata
from .agents_search_response_agents_item_memory import AgentsSearchResponseAgentsItemMemory
from .agents_search_response_agents_item_tools_item import AgentsSearchResponseAgentsItemToolsItem
from .agents_search_response_agents_item_sources_item import AgentsSearchResponseAgentsItemSourcesItem
from .agents_search_response_agents_item_tool_exec_environment_variables import (
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariables,
)
from .agents_search_response_agents_item_project_id import AgentsSearchResponseAgentsItemProjectId
from .agents_search_response_agents_item_template_id import AgentsSearchResponseAgentsItemTemplateId
from .agents_search_response_agents_item_base_template_id import AgentsSearchResponseAgentsItemBaseTemplateId
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class AgentsSearchResponseAgentsItem(UncheckedBaseModel):
    created_by_id: typing.Optional[AgentsSearchResponseAgentsItemCreatedById] = None
    last_updated_by_id: typing.Optional[AgentsSearchResponseAgentsItemLastUpdatedById] = None
    created_at: typing.Optional[AgentsSearchResponseAgentsItemCreatedAt] = None
    updated_at: typing.Optional[AgentsSearchResponseAgentsItemUpdatedAt] = None
    id: str
    name: str
    tool_rules: typing.Optional[AgentsSearchResponseAgentsItemToolRules] = None
    message_ids: typing.Optional[AgentsSearchResponseAgentsItemMessageIds] = None
    system: str
    agent_type: AgentsSearchResponseAgentsItemAgentType
    llm_config: AgentsSearchResponseAgentsItemLlmConfig
    embedding_config: AgentsSearchResponseAgentsItemEmbeddingConfig
    organization_id: typing.Optional[AgentsSearchResponseAgentsItemOrganizationId] = None
    description: typing.Optional[AgentsSearchResponseAgentsItemDescription] = None
    metadata: typing.Optional[AgentsSearchResponseAgentsItemMetadata] = None
    memory: AgentsSearchResponseAgentsItemMemory
    tools: typing.List[AgentsSearchResponseAgentsItemToolsItem]
    sources: typing.List[AgentsSearchResponseAgentsItemSourcesItem]
    tags: typing.List[str]
    tool_exec_environment_variables: typing.Optional[AgentsSearchResponseAgentsItemToolExecEnvironmentVariables] = None
    project_id: typing.Optional[AgentsSearchResponseAgentsItemProjectId] = None
    template_id: typing.Optional[AgentsSearchResponseAgentsItemTemplateId] = None
    base_template_id: typing.Optional[AgentsSearchResponseAgentsItemBaseTemplateId] = None
    template: typing.Optional[str] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_embedding_endpoint_type import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType,
)
import typing
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_embedding_endpoint import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_embedding_chunk_size import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_handle import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandle,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_azure_endpoint import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_azure_version import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_azure_deployment import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfig(UncheckedBaseModel):
    embedding_endpoint_type: (
        TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType
    )
    embedding_endpoint: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint
    ] = None
    embedding_model: str
    embedding_dim: float
    embedding_chunk_size: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize
    ] = None
    handle: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandle] = None
    azure_endpoint: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint
    ] = None
    azure_version: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion
    ] = None
    azure_deployment: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_tools_item_source_type_item import (
    AgentsSearchResponseAgentsItemToolsItemSourceTypeItem,
)

AgentsSearchResponseAgentsItemToolsItemSourceType = typing.Union[
    str, typing.Optional[str], typing.List[typing.Optional[AgentsSearchResponseAgentsItemToolsItemSourceTypeItem]]
]



# This file was auto-generated by Fern from our API Definition.

import typing

TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping = (
    typing.Union[bool, typing.Optional[typing.Any]]
)



# This file was auto-generated by Fern from our API Definition.

import typing
from .tool_call import ToolCall
from .tool_call_delta import ToolCallDelta

ToolCallMessageToolCall = typing.Union[ToolCall, ToolCallDelta]



# This file was auto-generated by Fern from our API Definition.

import typing

AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping = typing.Union[
    bool, typing.Optional[typing.Any]
]



# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
from .agents_search_response_agents_item_sources_item_embedding_config_embedding_endpoint_type import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType,
)
import typing
from .agents_search_response_agents_item_sources_item_embedding_config_embedding_endpoint import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint,
)
from .agents_search_response_agents_item_sources_item_embedding_config_embedding_chunk_size import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize,
)
from .agents_search_response_agents_item_sources_item_embedding_config_handle import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandle,
)
from .agents_search_response_agents_item_sources_item_embedding_config_azure_endpoint import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint,
)
from .agents_search_response_agents_item_sources_item_embedding_config_azure_version import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion,
)
from .agents_search_response_agents_item_sources_item_embedding_config_azure_deployment import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfig(UncheckedBaseModel):
    embedding_endpoint_type: AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType
    embedding_endpoint: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint] = (
        None
    )
    embedding_model: str
    embedding_dim: float
    embedding_chunk_size: typing.Optional[
        AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize
    ] = None
    handle: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandle] = None
    azure_endpoint: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint] = None
    azure_version: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion] = None
    azure_deployment: typing.Optional[AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_item_children import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildren,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_item_one import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemOne,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_item_two import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemTwo,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_item_child_output_mapping import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMapping,
)

TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItem = typing.Union[
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildren,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemOne,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemTwo,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMapping,
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_tools_item_organization_id_item import (
    AgentsSearchResponseAgentsItemToolsItemOrganizationIdItem,
)

AgentsSearchResponseAgentsItemToolsItemOrganizationId = typing.Union[
    str, typing.Optional[str], typing.List[typing.Optional[AgentsSearchResponseAgentsItemToolsItemOrganizationIdItem]]
]



# This file was auto-generated by Fern from our API Definition.

import typing

TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemDescriptionItem = typing.Union[str, typing.Optional[str]]



# This file was auto-generated by Fern from our API Definition.

import typing
from .chat_completion_content_part_text_param import ChatCompletionContentPartTextParam
from .chat_completion_content_part_image_param import ChatCompletionContentPartImageParam
from .chat_completion_content_part_input_audio_param import ChatCompletionContentPartInputAudioParam

ChatCompletionUserMessageParamContentItem = typing.Union[
    ChatCompletionContentPartTextParam, ChatCompletionContentPartImageParam, ChatCompletionContentPartInputAudioParam
]



# This file was auto-generated by Fern from our API Definition.

from .templates_create_agents_from_template_response import TemplatesCreateAgentsFromTemplateResponse
from .templates_create_agents_from_template_response_agents_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItem,
)
from .templates_create_agents_from_template_response_agents_item_agent_type import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemAgentType,
)
from .templates_create_agents_from_template_response_agents_item_base_template_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemBaseTemplateId,
)
from .templates_create_agents_from_template_response_agents_item_base_template_id_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemBaseTemplateIdItem,
)
from .templates_create_agents_from_template_response_agents_item_created_at import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedAt,
)
from .templates_create_agents_from_template_response_agents_item_created_at_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedAtItem,
)
from .templates_create_agents_from_template_response_agents_item_created_by_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedById,
)
from .templates_create_agents_from_template_response_agents_item_created_by_id_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedByIdItem,
)
from .templates_create_agents_from_template_response_agents_item_description import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemDescription,
)
from .templates_create_agents_from_template_response_agents_item_description_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemDescriptionItem,
)
from .templates_create_agents_from_template_response_agents_item_embedding_config import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfig,
)
from .templates_create_agents_from_template_response_agents_item_embedding_config_azure_deployment import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureDeployment,
)
from .templates_create_agents_from_template_response_agents_item_embedding_config_azure_deployment_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureDeploymentItem,
)
from .templates_create_agents_from_template_response_agents_item_embedding_config_azure_endpoint import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureEndpoint,
)
from .templates_create_agents_from_template_response_agents_item_embedding_config_azure_endpoint_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureEndpointItem,
)
from .templates_create_agents_from_template_response_agents_item_embedding_config_azure_version import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureVersion,
)
from .templates_create_agents_from_template_response_agents_item_embedding_config_azure_version_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureVersionItem,
)
from .templates_create_agents_from_template_response_agents_item_embedding_config_embedding_chunk_size import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingChunkSize,
)
from .templates_create_agents_from_template_response_agents_item_embedding_config_embedding_chunk_size_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem,
)
from .templates_create_agents_from_template_response_agents_item_embedding_config_embedding_endpoint import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingEndpoint,
)
from .templates_create_agents_from_template_response_agents_item_embedding_config_embedding_endpoint_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem,
)
from .templates_create_agents_from_template_response_agents_item_embedding_config_embedding_endpoint_type import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingEndpointType,
)
from .templates_create_agents_from_template_response_agents_item_embedding_config_handle import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigHandle,
)
from .templates_create_agents_from_template_response_agents_item_embedding_config_handle_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigHandleItem,
)
from .templates_create_agents_from_template_response_agents_item_last_updated_by_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLastUpdatedById,
)
from .templates_create_agents_from_template_response_agents_item_last_updated_by_id_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLastUpdatedByIdItem,
)
from .templates_create_agents_from_template_response_agents_item_llm_config import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfig,
)
from .templates_create_agents_from_template_response_agents_item_llm_config_handle import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigHandle,
)
from .templates_create_agents_from_template_response_agents_item_llm_config_handle_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigHandleItem,
)
from .templates_create_agents_from_template_response_agents_item_llm_config_max_tokens import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigMaxTokens,
)
from .templates_create_agents_from_template_response_agents_item_llm_config_max_tokens_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigMaxTokensItem,
)
from .templates_create_agents_from_template_response_agents_item_llm_config_model_endpoint import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpoint,
)
from .templates_create_agents_from_template_response_agents_item_llm_config_model_endpoint_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpointItem,
)
from .templates_create_agents_from_template_response_agents_item_llm_config_model_endpoint_type import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpointType,
)
from .templates_create_agents_from_template_response_agents_item_llm_config_model_wrapper import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelWrapper,
)
from .templates_create_agents_from_template_response_agents_item_llm_config_model_wrapper_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelWrapperItem,
)
from .templates_create_agents_from_template_response_agents_item_llm_config_put_inner_thoughts_in_kwargs import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs,
)
from .templates_create_agents_from_template_response_agents_item_llm_config_put_inner_thoughts_in_kwargs_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem,
)
from .templates_create_agents_from_template_response_agents_item_llm_config_temperature import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigTemperature,
)
from .templates_create_agents_from_template_response_agents_item_memory import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemory,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItem,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_created_by_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemCreatedById,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_created_by_id_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemCreatedByIdItem,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_description import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemDescription,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_description_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemDescriptionItem,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemId,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_is_template import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemIsTemplate,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_label import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLabel,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_label_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLabelItem,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_last_updated_by_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLastUpdatedById,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_last_updated_by_id_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_limit import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLimit,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_metadata import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemMetadata,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_metadata_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemMetadataItem,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_name import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemName,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_name_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemNameItem,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_organization_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemOrganizationId,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_organization_id_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemOrganizationIdItem,
)
from .templates_create_agents_from_template_response_agents_item_memory_prompt_template import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryPromptTemplate,
)
from .templates_create_agents_from_template_response_agents_item_message_ids import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIds,
)
from .templates_create_agents_from_template_response_agents_item_message_ids_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIdsItem,
)
from .templates_create_agents_from_template_response_agents_item_metadata import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMetadata,
)
from .templates_create_agents_from_template_response_agents_item_metadata_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMetadataItem,
)
from .templates_create_agents_from_template_response_agents_item_organization_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemOrganizationId,
)
from .templates_create_agents_from_template_response_agents_item_organization_id_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemOrganizationIdItem,
)
from .templates_create_agents_from_template_response_agents_item_project_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemProjectId,
)
from .templates_create_agents_from_template_response_agents_item_project_id_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemProjectIdItem,
)
from .templates_create_agents_from_template_response_agents_item_sources_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItem,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_created_at import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedAt,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_created_at_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedAtItem,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_created_by_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedById,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_created_by_id_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedByIdItem,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_description import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemDescription,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_description_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemDescriptionItem,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfig,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_azure_deployment import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_azure_deployment_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_azure_endpoint import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_azure_endpoint_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_azure_version import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_azure_version_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_embedding_chunk_size import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_embedding_chunk_size_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_embedding_endpoint import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_embedding_endpoint_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_embedding_endpoint_type import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_handle import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandle,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_embedding_config_handle_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandleItem,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemId,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_last_updated_by_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemLastUpdatedById,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_last_updated_by_id_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemLastUpdatedByIdItem,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_metadata import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemMetadata,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_metadata_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemMetadataItem,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_organization_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemOrganizationId,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_organization_id_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemOrganizationIdItem,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_updated_at import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemUpdatedAt,
)
from .templates_create_agents_from_template_response_agents_item_sources_item_updated_at_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemUpdatedAtItem,
)
from .templates_create_agents_from_template_response_agents_item_template_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemTemplateId,
)
from .templates_create_agents_from_template_response_agents_item_template_id_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemTemplateIdItem,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariables,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItem,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_created_at import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_created_at_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_created_by_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_created_by_id_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_description import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemDescription,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_description_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemId,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_last_updated_by_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_last_updated_by_id_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_organization_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_organization_id_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_updated_at import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_updated_at_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRules,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItem,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_child_output_mapping import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMapping,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_child_output_mapping_default_child import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_child_output_mapping_default_child_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_child_output_mapping_require_output_mapping import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_child_output_mapping_type import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingType,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_children import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildren,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_children_type import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildrenType,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItem,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_item_child_output_mapping import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMapping,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_item_child_output_mapping_default_child import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_item_child_output_mapping_default_child_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_item_child_output_mapping_require_output_mapping import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_item_child_output_mapping_type import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingType,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_item_children import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildren,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_item_children_type import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildrenType,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_item_one import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemOne,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_item_one_type import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemOneType,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_item_two import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemTwo,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_item_two_type import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemTwoType,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_one import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemOne,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_one_type import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemOneType,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_two import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemTwo,
)
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_two_type import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemTwoType,
)
from .templates_create_agents_from_template_response_agents_item_tools_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItem,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_created_by_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemCreatedById,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_created_by_id_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemCreatedByIdItem,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_description import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemDescription,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_description_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemDescriptionItem,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_json_schema import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemJsonSchema,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_json_schema_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemJsonSchemaItem,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_last_updated_by_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemLastUpdatedById,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_last_updated_by_id_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemLastUpdatedByIdItem,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_name import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemName,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_name_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemNameItem,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_organization_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemOrganizationId,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_organization_id_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemOrganizationIdItem,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_source_code import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceCode,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_source_code_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceCodeItem,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_source_type import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceType,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_source_type_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceTypeItem,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_tool_type import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemToolType,
)
from .templates_create_agents_from_template_response_agents_item_updated_at import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemUpdatedAt,
)
from .templates_create_agents_from_template_response_agents_item_updated_at_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemUpdatedAtItem,
)

__all__ = [
    "TemplatesCreateAgentsFromTemplateResponse",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemAgentType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemBaseTemplateId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemBaseTemplateIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedAt",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedAtItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemDescription",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemDescriptionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfig",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureDeployment",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureDeploymentItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureEndpoint",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureEndpointItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureVersion",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureVersionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingChunkSize",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingEndpoint",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingEndpointType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigHandle",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigHandleItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLastUpdatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfig",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigHandle",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigHandleItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigMaxTokens",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigMaxTokensItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpoint",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpointItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpointType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelWrapper",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelWrapperItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigTemperature",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemory",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemCreatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemCreatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemDescription",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemDescriptionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemIsTemplate",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLabel",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLabelItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLastUpdatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLimit",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemMetadata",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemMetadataItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemName",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemNameItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemOrganizationId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemOrganizationIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryPromptTemplate",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIds",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIdsItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMetadata",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMetadataItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemOrganizationId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemOrganizationIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemProjectId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemProjectIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedAt",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedAtItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemDescription",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemDescriptionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfig",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandle",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandleItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemLastUpdatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemMetadata",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemMetadataItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemOrganizationId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemOrganizationIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemUpdatedAt",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemUpdatedAtItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemTemplateId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemTemplateIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariables",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemDescription",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRules",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMapping",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildren",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildrenType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMapping",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildren",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildrenType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemOne",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemOneType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemTwo",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemTwoType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemOne",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemOneType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemTwo",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemTwoType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemCreatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemCreatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemDescription",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemDescriptionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemJsonSchema",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemJsonSchemaItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemLastUpdatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemName",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemNameItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemOrganizationId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemOrganizationIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceCode",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceCodeItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceTypeItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemToolType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemUpdatedAt",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemUpdatedAtItem",
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .agents_search_response_agents_item_sources_item_embedding_config_embedding_chunk_size_item import (
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem,
)

AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize = typing.Union[
    float,
    typing.Optional[str],
    typing.List[typing.Optional[AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem]],
    typing.Optional[typing.Any],
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_from_template_response_agents_item_tool_rules_item_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItem,
)

TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItem = typing.Union[
    typing.List[TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItem], typing.Optional[str]
]



# This file was auto-generated by Fern from our API Definition.

import typing

TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemTwoType = typing.Union[
    typing.Literal["exit_loop"], typing.Optional[typing.Any]
]



# This file was auto-generated by Fern from our API Definition.

import typing

AgentsSearchResponseAgentsItemMemoryBlocksItemMetadataItem = typing.Union[
    typing.Optional[typing.Any], typing.Optional[str]
]



# This file was auto-generated by Fern from our API Definition.

from ..core.unchecked_base_model import UncheckedBaseModel
import typing
from .audio import Audio
from .chat_completion_assistant_message_param_content import ChatCompletionAssistantMessageParamContent
from .function_call import FunctionCall
from .chat_completion_message_tool_call_param import ChatCompletionMessageToolCallParam
from ..core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class ChatCompletionAssistantMessageParam(UncheckedBaseModel):
    role: typing.Literal["assistant"] = "assistant"
    audio: typing.Optional[Audio] = None
    content: typing.Optional[ChatCompletionAssistantMessageParamContent] = None
    function_call: typing.Optional[FunctionCall] = None
    name: typing.Optional[str] = None
    refusal: typing.Optional[str] = None
    tool_calls: typing.Optional[typing.List[ChatCompletionMessageToolCallParam]] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_created_by_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_last_updated_by_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_created_at import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_updated_at import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemId,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_description import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemDescription,
)
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item_organization_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItem(UncheckedBaseModel):
    created_by_id: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById
    ] = None
    last_updated_by_id: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById
    ] = None
    created_at: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt
    ] = None
    updated_at: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt
    ] = None
    id: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemId] = None
    key: str
    value: str
    description: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemDescription
    ] = None
    organization_id: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId
    ] = None
    agent_id: str

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
from .agents_search_response_agents_item_llm_config_model_endpoint_type import (
    AgentsSearchResponseAgentsItemLlmConfigModelEndpointType,
)
import typing
from .agents_search_response_agents_item_llm_config_model_endpoint import (
    AgentsSearchResponseAgentsItemLlmConfigModelEndpoint,
)
from .agents_search_response_agents_item_llm_config_model_wrapper import (
    AgentsSearchResponseAgentsItemLlmConfigModelWrapper,
)
from .agents_search_response_agents_item_llm_config_put_inner_thoughts_in_kwargs import (
    AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs,
)
from .agents_search_response_agents_item_llm_config_handle import AgentsSearchResponseAgentsItemLlmConfigHandle
from .agents_search_response_agents_item_llm_config_temperature import (
    AgentsSearchResponseAgentsItemLlmConfigTemperature,
)
from .agents_search_response_agents_item_llm_config_max_tokens import AgentsSearchResponseAgentsItemLlmConfigMaxTokens
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class AgentsSearchResponseAgentsItemLlmConfig(UncheckedBaseModel):
    model: str
    model_endpoint_type: AgentsSearchResponseAgentsItemLlmConfigModelEndpointType
    model_endpoint: typing.Optional[AgentsSearchResponseAgentsItemLlmConfigModelEndpoint] = None
    model_wrapper: typing.Optional[AgentsSearchResponseAgentsItemLlmConfigModelWrapper] = None
    context_window: float
    put_inner_thoughts_in_kwargs: typing.Optional[AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs] = (
        None
    )
    handle: typing.Optional[AgentsSearchResponseAgentsItemLlmConfigHandle] = None
    temperature: typing.Optional[AgentsSearchResponseAgentsItemLlmConfigTemperature] = None
    max_tokens: typing.Optional[AgentsSearchResponseAgentsItemLlmConfigMaxTokens] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_limit import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLimit,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_name import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemName,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_is_template import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemIsTemplate,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_label import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLabel,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_description import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemDescription,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_metadata import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemMetadata,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemId,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_organization_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemOrganizationId,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_created_by_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemCreatedById,
)
from .templates_create_agents_from_template_response_agents_item_memory_blocks_item_last_updated_by_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLastUpdatedById,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItem(UncheckedBaseModel):
    value: str
    limit: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLimit] = None
    name: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemName] = None
    is_template: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemIsTemplate] = None
    label: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLabel] = None
    description: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemDescription] = None
    metadata: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemMetadata] = None
    id: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemId] = None
    organization_id: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemOrganizationId
    ] = None
    created_by_id: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemCreatedById] = (
        None
    )
    last_updated_by_id: typing.Optional[
        TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLastUpdatedById
    ] = None

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

from .types import (
    AgentsSearchRequestSearchItem,
    AgentsSearchRequestSearchItemField,
    AgentsSearchRequestSearchItemOne,
    AgentsSearchRequestSearchItemOneOperator,
    AgentsSearchRequestSearchItemZero,
    AgentsSearchResponse,
    AgentsSearchResponseAgentsItem,
    AgentsSearchResponseAgentsItemAgentType,
    AgentsSearchResponseAgentsItemBaseTemplateId,
    AgentsSearchResponseAgentsItemBaseTemplateIdItem,
    AgentsSearchResponseAgentsItemCreatedAt,
    AgentsSearchResponseAgentsItemCreatedAtItem,
    AgentsSearchResponseAgentsItemCreatedById,
    AgentsSearchResponseAgentsItemCreatedByIdItem,
    AgentsSearchResponseAgentsItemDescription,
    AgentsSearchResponseAgentsItemDescriptionItem,
    AgentsSearchResponseAgentsItemEmbeddingConfig,
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureDeployment,
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureDeploymentItem,
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureEndpoint,
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureEndpointItem,
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureVersion,
    AgentsSearchResponseAgentsItemEmbeddingConfigAzureVersionItem,
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingChunkSize,
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem,
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpoint,
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem,
    AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpointType,
    AgentsSearchResponseAgentsItemEmbeddingConfigHandle,
    AgentsSearchResponseAgentsItemEmbeddingConfigHandleItem,
    AgentsSearchResponseAgentsItemLastUpdatedById,
    AgentsSearchResponseAgentsItemLastUpdatedByIdItem,
    AgentsSearchResponseAgentsItemLlmConfig,
    AgentsSearchResponseAgentsItemLlmConfigHandle,
    AgentsSearchResponseAgentsItemLlmConfigHandleItem,
    AgentsSearchResponseAgentsItemLlmConfigMaxTokens,
    AgentsSearchResponseAgentsItemLlmConfigMaxTokensItem,
    AgentsSearchResponseAgentsItemLlmConfigModelEndpoint,
    AgentsSearchResponseAgentsItemLlmConfigModelEndpointItem,
    AgentsSearchResponseAgentsItemLlmConfigModelEndpointType,
    AgentsSearchResponseAgentsItemLlmConfigModelWrapper,
    AgentsSearchResponseAgentsItemLlmConfigModelWrapperItem,
    AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs,
    AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem,
    AgentsSearchResponseAgentsItemLlmConfigTemperature,
    AgentsSearchResponseAgentsItemMemory,
    AgentsSearchResponseAgentsItemMemoryBlocksItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedById,
    AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedByIdItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemDescription,
    AgentsSearchResponseAgentsItemMemoryBlocksItemDescriptionItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemId,
    AgentsSearchResponseAgentsItemMemoryBlocksItemIsTemplate,
    AgentsSearchResponseAgentsItemMemoryBlocksItemLabel,
    AgentsSearchResponseAgentsItemMemoryBlocksItemLabelItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedById,
    AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemLimit,
    AgentsSearchResponseAgentsItemMemoryBlocksItemMetadata,
    AgentsSearchResponseAgentsItemMemoryBlocksItemMetadataItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemName,
    AgentsSearchResponseAgentsItemMemoryBlocksItemNameItem,
    AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationId,
    AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationIdItem,
    AgentsSearchResponseAgentsItemMemoryPromptTemplate,
    AgentsSearchResponseAgentsItemMessageIds,
    AgentsSearchResponseAgentsItemMessageIdsItem,
    AgentsSearchResponseAgentsItemMetadata,
    AgentsSearchResponseAgentsItemMetadataItem,
    AgentsSearchResponseAgentsItemOrganizationId,
    AgentsSearchResponseAgentsItemOrganizationIdItem,
    AgentsSearchResponseAgentsItemProjectId,
    AgentsSearchResponseAgentsItemProjectIdItem,
    AgentsSearchResponseAgentsItemSourcesItem,
    AgentsSearchResponseAgentsItemSourcesItemCreatedAt,
    AgentsSearchResponseAgentsItemSourcesItemCreatedAtItem,
    AgentsSearchResponseAgentsItemSourcesItemCreatedById,
    AgentsSearchResponseAgentsItemSourcesItemCreatedByIdItem,
    AgentsSearchResponseAgentsItemSourcesItemDescription,
    AgentsSearchResponseAgentsItemSourcesItemDescriptionItem,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfig,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandle,
    AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandleItem,
    AgentsSearchResponseAgentsItemSourcesItemId,
    AgentsSearchResponseAgentsItemSourcesItemLastUpdatedById,
    AgentsSearchResponseAgentsItemSourcesItemLastUpdatedByIdItem,
    AgentsSearchResponseAgentsItemSourcesItemMetadata,
    AgentsSearchResponseAgentsItemSourcesItemMetadataItem,
    AgentsSearchResponseAgentsItemSourcesItemOrganizationId,
    AgentsSearchResponseAgentsItemSourcesItemOrganizationIdItem,
    AgentsSearchResponseAgentsItemSourcesItemUpdatedAt,
    AgentsSearchResponseAgentsItemSourcesItemUpdatedAtItem,
    AgentsSearchResponseAgentsItemTemplateId,
    AgentsSearchResponseAgentsItemTemplateIdItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariables,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescription,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemId,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt,
    AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem,
    AgentsSearchResponseAgentsItemToolRules,
    AgentsSearchResponseAgentsItemToolRulesItem,
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMapping,
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild,
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem,
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping,
    AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingType,
    AgentsSearchResponseAgentsItemToolRulesItemChildren,
    AgentsSearchResponseAgentsItemToolRulesItemChildrenType,
    AgentsSearchResponseAgentsItemToolRulesItemItem,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMapping,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingType,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildren,
    AgentsSearchResponseAgentsItemToolRulesItemItemChildrenType,
    AgentsSearchResponseAgentsItemToolRulesItemItemOne,
    AgentsSearchResponseAgentsItemToolRulesItemItemOneType,
    AgentsSearchResponseAgentsItemToolRulesItemItemTwo,
    AgentsSearchResponseAgentsItemToolRulesItemItemTwoType,
    AgentsSearchResponseAgentsItemToolRulesItemOne,
    AgentsSearchResponseAgentsItemToolRulesItemOneType,
    AgentsSearchResponseAgentsItemToolRulesItemTwo,
    AgentsSearchResponseAgentsItemToolRulesItemTwoType,
    AgentsSearchResponseAgentsItemToolsItem,
    AgentsSearchResponseAgentsItemToolsItemCreatedById,
    AgentsSearchResponseAgentsItemToolsItemCreatedByIdItem,
    AgentsSearchResponseAgentsItemToolsItemDescription,
    AgentsSearchResponseAgentsItemToolsItemDescriptionItem,
    AgentsSearchResponseAgentsItemToolsItemJsonSchema,
    AgentsSearchResponseAgentsItemToolsItemJsonSchemaItem,
    AgentsSearchResponseAgentsItemToolsItemLastUpdatedById,
    AgentsSearchResponseAgentsItemToolsItemLastUpdatedByIdItem,
    AgentsSearchResponseAgentsItemToolsItemName,
    AgentsSearchResponseAgentsItemToolsItemNameItem,
    AgentsSearchResponseAgentsItemToolsItemOrganizationId,
    AgentsSearchResponseAgentsItemToolsItemOrganizationIdItem,
    AgentsSearchResponseAgentsItemToolsItemSourceCode,
    AgentsSearchResponseAgentsItemToolsItemSourceCodeItem,
    AgentsSearchResponseAgentsItemToolsItemSourceType,
    AgentsSearchResponseAgentsItemToolsItemSourceTypeItem,
    AgentsSearchResponseAgentsItemToolsItemToolType,
    AgentsSearchResponseAgentsItemUpdatedAt,
    AgentsSearchResponseAgentsItemUpdatedAtItem,
    CreateAgentRequestToolRulesItem,
    UpdateAgentToolRulesItem,
)
from . import archival_memory, context, core_memory, memory_variables, messages, sources, templates, tools
from .memory_variables import MemoryVariablesListResponse
from .messages import LettaStreamingResponse, MessageUpdateContent
from .templates import TemplatesCreateResponse, TemplatesMigrateResponse

__all__ = [
    "AgentsSearchRequestSearchItem",
    "AgentsSearchRequestSearchItemField",
    "AgentsSearchRequestSearchItemOne",
    "AgentsSearchRequestSearchItemOneOperator",
    "AgentsSearchRequestSearchItemZero",
    "AgentsSearchResponse",
    "AgentsSearchResponseAgentsItem",
    "AgentsSearchResponseAgentsItemAgentType",
    "AgentsSearchResponseAgentsItemBaseTemplateId",
    "AgentsSearchResponseAgentsItemBaseTemplateIdItem",
    "AgentsSearchResponseAgentsItemCreatedAt",
    "AgentsSearchResponseAgentsItemCreatedAtItem",
    "AgentsSearchResponseAgentsItemCreatedById",
    "AgentsSearchResponseAgentsItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemDescription",
    "AgentsSearchResponseAgentsItemDescriptionItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfig",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureDeployment",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureDeploymentItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureEndpoint",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureEndpointItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureVersion",
    "AgentsSearchResponseAgentsItemEmbeddingConfigAzureVersionItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingChunkSize",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpoint",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem",
    "AgentsSearchResponseAgentsItemEmbeddingConfigEmbeddingEndpointType",
    "AgentsSearchResponseAgentsItemEmbeddingConfigHandle",
    "AgentsSearchResponseAgentsItemEmbeddingConfigHandleItem",
    "AgentsSearchResponseAgentsItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemLlmConfig",
    "AgentsSearchResponseAgentsItemLlmConfigHandle",
    "AgentsSearchResponseAgentsItemLlmConfigHandleItem",
    "AgentsSearchResponseAgentsItemLlmConfigMaxTokens",
    "AgentsSearchResponseAgentsItemLlmConfigMaxTokensItem",
    "AgentsSearchResponseAgentsItemLlmConfigModelEndpoint",
    "AgentsSearchResponseAgentsItemLlmConfigModelEndpointItem",
    "AgentsSearchResponseAgentsItemLlmConfigModelEndpointType",
    "AgentsSearchResponseAgentsItemLlmConfigModelWrapper",
    "AgentsSearchResponseAgentsItemLlmConfigModelWrapperItem",
    "AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs",
    "AgentsSearchResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem",
    "AgentsSearchResponseAgentsItemLlmConfigTemperature",
    "AgentsSearchResponseAgentsItemMemory",
    "AgentsSearchResponseAgentsItemMemoryBlocksItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedById",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemDescription",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemDescriptionItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemId",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemIsTemplate",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLabel",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLabelItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemLimit",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemMetadata",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemMetadataItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemName",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemNameItem",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationId",
    "AgentsSearchResponseAgentsItemMemoryBlocksItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemMemoryPromptTemplate",
    "AgentsSearchResponseAgentsItemMessageIds",
    "AgentsSearchResponseAgentsItemMessageIdsItem",
    "AgentsSearchResponseAgentsItemMetadata",
    "AgentsSearchResponseAgentsItemMetadataItem",
    "AgentsSearchResponseAgentsItemOrganizationId",
    "AgentsSearchResponseAgentsItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemProjectId",
    "AgentsSearchResponseAgentsItemProjectIdItem",
    "AgentsSearchResponseAgentsItemSourcesItem",
    "AgentsSearchResponseAgentsItemSourcesItemCreatedAt",
    "AgentsSearchResponseAgentsItemSourcesItemCreatedAtItem",
    "AgentsSearchResponseAgentsItemSourcesItemCreatedById",
    "AgentsSearchResponseAgentsItemSourcesItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemSourcesItemDescription",
    "AgentsSearchResponseAgentsItemSourcesItemDescriptionItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfig",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandle",
    "AgentsSearchResponseAgentsItemSourcesItemEmbeddingConfigHandleItem",
    "AgentsSearchResponseAgentsItemSourcesItemId",
    "AgentsSearchResponseAgentsItemSourcesItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemSourcesItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemSourcesItemMetadata",
    "AgentsSearchResponseAgentsItemSourcesItemMetadataItem",
    "AgentsSearchResponseAgentsItemSourcesItemOrganizationId",
    "AgentsSearchResponseAgentsItemSourcesItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemSourcesItemUpdatedAt",
    "AgentsSearchResponseAgentsItemSourcesItemUpdatedAtItem",
    "AgentsSearchResponseAgentsItemTemplateId",
    "AgentsSearchResponseAgentsItemTemplateIdItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariables",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescription",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemId",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt",
    "AgentsSearchResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem",
    "AgentsSearchResponseAgentsItemToolRules",
    "AgentsSearchResponseAgentsItemToolRulesItem",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMapping",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping",
    "AgentsSearchResponseAgentsItemToolRulesItemChildOutputMappingType",
    "AgentsSearchResponseAgentsItemToolRulesItemChildren",
    "AgentsSearchResponseAgentsItemToolRulesItemChildrenType",
    "AgentsSearchResponseAgentsItemToolRulesItemItem",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMapping",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildOutputMappingType",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildren",
    "AgentsSearchResponseAgentsItemToolRulesItemItemChildrenType",
    "AgentsSearchResponseAgentsItemToolRulesItemItemOne",
    "AgentsSearchResponseAgentsItemToolRulesItemItemOneType",
    "AgentsSearchResponseAgentsItemToolRulesItemItemTwo",
    "AgentsSearchResponseAgentsItemToolRulesItemItemTwoType",
    "AgentsSearchResponseAgentsItemToolRulesItemOne",
    "AgentsSearchResponseAgentsItemToolRulesItemOneType",
    "AgentsSearchResponseAgentsItemToolRulesItemTwo",
    "AgentsSearchResponseAgentsItemToolRulesItemTwoType",
    "AgentsSearchResponseAgentsItemToolsItem",
    "AgentsSearchResponseAgentsItemToolsItemCreatedById",
    "AgentsSearchResponseAgentsItemToolsItemCreatedByIdItem",
    "AgentsSearchResponseAgentsItemToolsItemDescription",
    "AgentsSearchResponseAgentsItemToolsItemDescriptionItem",
    "AgentsSearchResponseAgentsItemToolsItemJsonSchema",
    "AgentsSearchResponseAgentsItemToolsItemJsonSchemaItem",
    "AgentsSearchResponseAgentsItemToolsItemLastUpdatedById",
    "AgentsSearchResponseAgentsItemToolsItemLastUpdatedByIdItem",
    "AgentsSearchResponseAgentsItemToolsItemName",
    "AgentsSearchResponseAgentsItemToolsItemNameItem",
    "AgentsSearchResponseAgentsItemToolsItemOrganizationId",
    "AgentsSearchResponseAgentsItemToolsItemOrganizationIdItem",
    "AgentsSearchResponseAgentsItemToolsItemSourceCode",
    "AgentsSearchResponseAgentsItemToolsItemSourceCodeItem",
    "AgentsSearchResponseAgentsItemToolsItemSourceType",
    "AgentsSearchResponseAgentsItemToolsItemSourceTypeItem",
    "AgentsSearchResponseAgentsItemToolsItemToolType",
    "AgentsSearchResponseAgentsItemUpdatedAt",
    "AgentsSearchResponseAgentsItemUpdatedAtItem",
    "CreateAgentRequestToolRulesItem",
    "LettaStreamingResponse",
    "MemoryVariablesListResponse",
    "MessageUpdateContent",
    "TemplatesCreateResponse",
    "TemplatesMigrateResponse",
    "UpdateAgentToolRulesItem",
    "archival_memory",
    "context",
    "core_memory",
    "memory_variables",
    "messages",
    "sources",
    "templates",
    "tools",
]



# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_from_template_response_agents_item_tool_exec_environment_variables_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItem,
)

TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariables = typing.Union[
    typing.List[TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItem],
    typing.Optional[typing.Any],
]



# This file was auto-generated by Fern from our API Definition.

from .types import (
    TemplatesCreateAgentsFromTemplateResponse,
    TemplatesCreateAgentsFromTemplateResponseAgentsItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemAgentType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemBaseTemplateId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemBaseTemplateIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedAt,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedAtItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemDescription,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemDescriptionItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfig,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureDeployment,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureDeploymentItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureEndpoint,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureEndpointItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureVersion,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureVersionItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingChunkSize,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingEndpoint,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingEndpointType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigHandle,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigHandleItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLastUpdatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLastUpdatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfig,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigHandle,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigHandleItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigMaxTokens,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigMaxTokensItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpoint,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpointItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpointType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelWrapper,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelWrapperItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigTemperature,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemory,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemCreatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemCreatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemDescription,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemDescriptionItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemIsTemplate,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLabel,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLabelItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLastUpdatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLimit,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemMetadata,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemMetadataItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemName,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemNameItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemOrganizationId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemOrganizationIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryPromptTemplate,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIds,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIdsItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMetadata,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemMetadataItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemOrganizationId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemOrganizationIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemProjectId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemProjectIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedAt,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedAtItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemDescription,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemDescriptionItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfig,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandle,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandleItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemLastUpdatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemLastUpdatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemMetadata,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemMetadataItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemOrganizationId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemOrganizationIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemUpdatedAt,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemUpdatedAtItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemTemplateId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemTemplateIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariables,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemDescription,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRules,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMapping,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildren,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildrenType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMapping,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildren,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildrenType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemOne,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemOneType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemTwo,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemTwoType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemOne,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemOneType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemTwo,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemTwoType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemCreatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemCreatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemDescription,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemDescriptionItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemJsonSchema,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemJsonSchemaItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemLastUpdatedById,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemLastUpdatedByIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemName,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemNameItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemOrganizationId,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemOrganizationIdItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceCode,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceCodeItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceTypeItem,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemToolType,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemUpdatedAt,
    TemplatesCreateAgentsFromTemplateResponseAgentsItemUpdatedAtItem,
)

__all__ = [
    "TemplatesCreateAgentsFromTemplateResponse",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemAgentType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemBaseTemplateId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemBaseTemplateIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedAt",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedAtItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemCreatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemDescription",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemDescriptionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfig",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureDeployment",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureDeploymentItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureEndpoint",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureEndpointItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureVersion",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigAzureVersionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingChunkSize",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingChunkSizeItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingEndpoint",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingEndpointItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigEmbeddingEndpointType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigHandle",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemEmbeddingConfigHandleItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLastUpdatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfig",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigHandle",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigHandleItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigMaxTokens",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigMaxTokensItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpoint",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpointItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelEndpointType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelWrapper",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigModelWrapperItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigPutInnerThoughtsInKwargs",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigPutInnerThoughtsInKwargsItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemLlmConfigTemperature",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemory",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemCreatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemCreatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemDescription",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemDescriptionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemIsTemplate",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLabel",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLabelItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLastUpdatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemLimit",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemMetadata",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemMetadataItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemName",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemNameItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemOrganizationId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryBlocksItemOrganizationIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMemoryPromptTemplate",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIds",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIdsItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMetadata",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemMetadataItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemOrganizationId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemOrganizationIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemProjectId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemProjectIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedAt",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedAtItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemCreatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemDescription",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemDescriptionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfig",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureDeployment",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureDeploymentItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpoint",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureEndpointItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureVersion",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigAzureVersionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSize",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingChunkSizeItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpoint",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigEmbeddingEndpointType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandle",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemEmbeddingConfigHandleItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemLastUpdatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemMetadata",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemMetadataItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemOrganizationId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemOrganizationIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemUpdatedAt",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemUpdatedAtItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemTemplateId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemTemplateIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariables",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAt",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedAtItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemCreatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemDescription",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemDescriptionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemOrganizationIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAt",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolExecEnvironmentVariablesItemUpdatedAtItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRules",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMapping",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingDefaultChild",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingDefaultChildItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingRequireOutputMapping",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildOutputMappingType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildren",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemChildrenType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMapping",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChild",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingDefaultChildItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingRequireOutputMapping",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildOutputMappingType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildren",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemChildrenType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemOne",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemOneType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemTwo",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemItemTwoType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemOne",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemOneType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemTwo",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolRulesItemTwoType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemCreatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemCreatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemDescription",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemDescriptionItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemJsonSchema",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemJsonSchemaItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemLastUpdatedById",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemLastUpdatedByIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemName",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemNameItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemOrganizationId",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemOrganizationIdItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceCode",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceCodeItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceTypeItem",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemToolType",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemUpdatedAt",
    "TemplatesCreateAgentsFromTemplateResponseAgentsItemUpdatedAtItem",
]



# This file was auto-generated by Fern from our API Definition.

import typing

TemplatesCreateAgentsFromTemplateResponseAgentsItemMessageIdsItem = typing.Union[typing.List[str], typing.Optional[str]]



# This file was auto-generated by Fern from our API Definition.

import typing
from .templates_create_agents_from_template_response_agents_item_sources_item_last_updated_by_id_item import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemLastUpdatedByIdItem,
)

TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemLastUpdatedById = typing.Union[
    str,
    typing.Optional[str],
    typing.List[typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemSourcesItemLastUpdatedByIdItem]],
    typing.Optional[typing.Any],
]



# This file was auto-generated by Fern from our API Definition.

from ...core.unchecked_base_model import UncheckedBaseModel
import typing
from .templates_create_agents_from_template_response_agents_item_tools_item_tool_type import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemToolType,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_description import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemDescription,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_source_type import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceType,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_organization_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemOrganizationId,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_name import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemName,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_source_code import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceCode,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_json_schema import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemJsonSchema,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_created_by_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemCreatedById,
)
from .templates_create_agents_from_template_response_agents_item_tools_item_last_updated_by_id import (
    TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemLastUpdatedById,
)
from ...core.pydantic_utilities import IS_PYDANTIC_V2
import pydantic


class TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItem(UncheckedBaseModel):
    id: typing.Optional[str] = None
    tool_type: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemToolType] = None
    description: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemDescription] = None
    source_type: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceType] = None
    organization_id: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemOrganizationId] = None
    name: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemName] = None
    tags: typing.Optional[typing.List[str]] = None
    source_code: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemSourceCode] = None
    json_schema: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemJsonSchema] = None
    return_char_limit: typing.Optional[float] = None
    created_by_id: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemCreatedById] = None
    last_updated_by_id: typing.Optional[TemplatesCreateAgentsFromTemplateResponseAgentsItemToolsItemLastUpdatedById] = (
        None
    )

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
